unit Example;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, Datatypes, DllInterface, StdCtrls, ExtCtrls, RzPanel, RzRadGrp;

type
  TForm1 = class(TForm)
    InitButton: TButton;
    InitDeviceEdit: TEdit;
    OpenDeviceButton: TButton;
    GetSerialNoButton: TButton;
    SerialNoEdit: TEdit;
    GetChannelButton: TButton;
    ChannelNoEdit: TEdit;
    GroupBox1: TGroupBox;
    ResetButton: TButton;
    StoreButton: TButton;
    RestoreButton: TButton;
    GroupBox2: TGroupBox;
    INormalMaxEdit: TEdit;
    INormalSetEdit: TEdit;
    NormalSetButton: TButton;
    CloseButton: TButton;
    GroupBox3: TGroupBox;
    GroupBox4: TGroupBox;
    IStrobeMaxEdit: TEdit;
    RepeatCntEdit: TEdit;
    StrobeSetButton: TButton;
    ITriggerMaxEdit: TEdit;
    PolarityEdit: TEdit;
    TriggerSetButton: TButton;
    Label1: TLabel;
    CurrentChannelEdit: TEdit;
    ChannelModeGroup: TRadioGroup;
    SetModeButton: TButton;
    GetModuleTypeButton: TButton;
    ModuleTypeEdit: TEdit;
    GroupBox5: TGroupBox;
    LoadVoltageEdit: TEdit;
    GetVoltageButton: TButton;
    procedure CloseButtonClick(Sender: TObject);
    procedure InitButtonClick(Sender: TObject);
    procedure OpenDeviceButtonClick(Sender: TObject);
    procedure GetSerialNoButtonClick(Sender: TObject);
    procedure GetChannelButtonClick(Sender: TObject);
    procedure SetModeButtonClick(Sender: TObject);
    procedure ResetButtonClick(Sender: TObject);
    procedure StoreButtonClick(Sender: TObject);
    procedure RestoreButtonClick(Sender: TObject);
    procedure NormalSetButtonClick(Sender: TObject);
    procedure StrobeSetButtonClick(Sender: TObject);
    procedure TriggerSetButtonClick(Sender: TObject);
    procedure GetModuleTypeButtonClick(Sender: TObject);
    procedure GetVoltageButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;
  DevHandle : integer;

implementation

{$R *.DFM}

procedure TForm1.CloseButtonClick(Sender: TObject);
begin
  MTUSB_LEDDriverCloseDevice( DevHandle );
  Close;
end;

procedure TForm1.InitButtonClick(Sender: TObject);
var
  Devices : integer;
begin
  Devices := MTUSB_LEDDriverInitDevices();
  InitDeviceEdit.Text := IntToStr( Devices );
end;

procedure TForm1.OpenDeviceButtonClick(Sender: TObject);
begin
  DevHandle :=  MTUSB_LEDDriverOpenDevice( 0 );
end;

procedure TForm1.GetSerialNoButtonClick(Sender: TObject);
var
  SerialNo : Array[0..31] of Char;
begin
  MTUSB_LEDDriverSerialNumber( DevHandle, @SerialNo[0], sizeof( SerialNo ) );
  SerialNoEdit.Text := String( SerialNo );
end;

procedure TForm1.GetChannelButtonClick(Sender: TObject);
var
  Channel : integer;
begin
  Channel := MTUSB_LEDDriverDeviceChannels( DevHandle );
  ChannelNoEdit.Text := IntToStr( Channel );
end;

procedure TForm1.SetModeButtonClick(Sender: TObject);
var
  Channel : integer;
begin
  Channel := StrToInt( CurrentChannelEdit.Text );
  MTUSB_LEDDriverSetMode( DevHandle, Channel, ChannelModeGroup.ItemIndex );
end;

procedure TForm1.ResetButtonClick(Sender: TObject);
begin
  MTUSB_LEDDriverResetDevice( DevHandle ); 
end;

procedure TForm1.StoreButtonClick(Sender: TObject);
begin
  MTUSB_LEDDriverStorePara( DevHandle );
end;

procedure TForm1.RestoreButtonClick(Sender: TObject);
begin
  MTUSB_LEDDriverRestoreDefault( DevHandle );
end;

procedure TForm1.NormalSetButtonClick(Sender: TObject);
var
  Channel : integer;
begin
  Channel := StrToInt( CurrentChannelEdit.Text );
  LedData.Normal_CurrentMax := StrToInt( INormalMaxEdit.Text );
  LedData.Normal_CurrentSet := StrToInt( INormalSetEdit.Text );
  MTUSB_LEDDriverSetNormalPara( DevHandle, Channel, @LedData );
  MTUSB_LEDDriverSetNormalCurrent( DevHandle, Channel, LedData.Normal_CurrentSet );
end;

procedure TForm1.StrobeSetButtonClick(Sender: TObject);
var
  Channel : integer;
begin
  Channel := StrToInt( CurrentChannelEdit.Text );
  LedData.Strobe_CurrentMax := StrToInt( IStrobeMaxEdit.Text );
  LedData.Strobe_RepeatCnt := StrToInt( RepeatCntEdit.Text );
  LedData.Strobe_Profile[1,1] := 200 ; // Iset
  LedData.Strobe_Profile[1,2] := 500000 ; // Tset
  LedData.Strobe_Profile[2,1] := 5  ;
  LedData.Strobe_Profile[2,2] := 500000;
  LedData.Strobe_Profile[3,1] := 0;
  LedData.Strobe_Profile[3,2] := 0;
  MTUSB_LEDDriverSetStrobePara( DevHandle, Channel, @LedData );
end;

procedure TForm1.TriggerSetButtonClick(Sender: TObject);
var
  Channel : integer;
begin
  Channel := StrToInt( CurrentChannelEdit.Text );
  LedData.Trigger_CurrentMax := StrToInt( ITriggerMaxEdit.Text );
  LedData.Trigger_Polarity := StrToInt( PolarityEdit.Text );
  LedData.Trigger_Profile[1,1] := 100 ; // Iset
  LedData.Trigger_Profile[1,2] := 200 ; // Tset
  LedData.Trigger_Profile[2,1] := 50  ;
  LedData.Trigger_Profile[2,2] := 2000;
  LedData.Trigger_Profile[3,1] := 0;
  LedData.Trigger_Profile[3,2] := 0;
  MTUSB_LEDDriverSetTriggerPara( DevHandle, Channel, @LedData );
end;

procedure TForm1.GetModuleTypeButtonClick(Sender: TObject);
var
  ModuleType : integer;
  ModuleTypeStr : String;
begin
  ModuleType := MTUSB_LEDDriverDeviceModuleType( DevHandle );
  case ModuleType of
    AA_MODULE: ModuleTypeStr:= 'AA';
    AV_MODULE: ModuleTypeStr:= 'AV';
    SA_MODULE: ModuleTypeStr:= 'SA';
    SV_MODULE: ModuleTypeStr:= 'SV';
    MA_MODULE: ModuleTypeStr:= 'MA';
    CA_MODULE: ModuleTypeStr:= 'CA';
  end;
  ModuleTypeEdit.Text := ModuleTypeStr;
end;

procedure TForm1.GetVoltageButtonClick(Sender: TObject);
var
  Voltage, Channel : integer;
begin
  Channel := StrToInt( CurrentChannelEdit.Text );
  Voltage := MTUSB_LEDDriverGetLoadVoltage( DevHandle, Channel );
  LoadVoltageEdit.Text := IntToStr( Voltage );
end;

end.
